var createError = require('http-errors');
var express = require('express');
var path = require('path');
var cookieParser = require('cookie-parser');
var logger = require('morgan');
const flash = require('connect-flash');
const session = require('express-session');
const passport = require('./passport-config');
const connectToDatabase = require('./database/connection');
const setUserIfAuthenticated = require('./routes/index').setUserIfAuthenticated;


var usersRouter = require('./routes/users');
var indexRouter = require('./routes/index');
const announcementsRouter = require('./routes/announcement');

var app = express();

connectToDatabase();

app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'pug');

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, 'public')));

app.use(session({ secret: 'fifiHajar', resave: true, saveUninitialized: true }));
app.use(passport.initialize());
app.use(passport.session());
app.use(flash());
app.use(setUserIfAuthenticated);

//app.use('/', authentifcationRouter);
//app.use('/', indexRouter);
app.use('/', indexRouter.router);
app.use('/users', usersRouter);
app.use('/announcements', announcementsRouter);

app.use(function(req, res, next) {
  var err = new Error('Not Found');
  err.status = 404;
  next(err);
});

app.use(function(err, req, res, next) {
  res.locals.message = err.message;
  res.locals.error = req.app.get('env') === 'development' ? err : {};
  res.status(err.status || 500);
  res.render('error');
});

module.exports = app;
